@@ -26,7 +26,7 @@ from torchvision.ops import ps_roi_align, ps_roi_pool, roi_align, roi_pool
 from torchvision.utils import save_image
 from tqdm import tqdm
 
-from utils.general import (
+from yolov7.utils.general import (
     check_requirements,
     clean_str,
     resample_segments,
